sensPlot creates a contour plot that summarizes the results of the sensitivity analysis obtained from GLM.sens. The plot region is defined by the coefficient on U in the outcome model (vertical axis) and that in the treatment model (horizontal axis). Each contour represents the combination of sensitivity parameters for U that lead to the same treatment effect estimate.
sensPlot(x, contour.levels = NULL, col.zero = "red", lty.zero = 1, col.insig = "blue", lty.insig = 1, data.line = TRUE, X.pch = NULL, signif.level = 0.05, labcex = 0.75, limit.Xplot = FALSE, txtlab = FALSE,
which.txtlab = NULL,...)sensitivity.
NULL.
"red".
1 (solid line).
"blue".
1 (solid line)
TRUE a grey contour corresponding to the treatment effect estimate obtained with sensitivity parameters set equal to the coefficients (across all observed confounders) that are farthest from the origin (0,0). The default is TRUE.
TRUE this option limits the plot region to the minimum and the maximum of the sensitivity parameters and the covariates are plotted on the left or the right end of the figure. If FALSE the contour is extended to the coefficient of the strongest confounders.
contour
treatSens,plot.default,plot.formula.
#See the manual for treatSens.
Run the code above in your browser using DataLab