Learn R Programming

treatSens (version 1.0)

treatSens-package: Sensitivity analysis for causal inference

Description

Utilities to investigate sensitivity to unmeasured confounding in causal models of several types.

Arguments

Details

ll{ Package: treatSens Type: Package Version: 0.1 Date: 2014-07-07 Depends: R (>= 2.13.0), lme4 Suggests: doSNOW License: GPL-2 LazyLoad: yes LazyData: yes Built: R 3.1.1; ; 2014-08-12 16:49:37 UTC; windows } Run dual-parameter sensitivity analysis for continuous response modeled with linear model using treatSens. Results are available in either tabular form using summary.sensitivity or graphical form using sensPlot.

References

Carnegie NB, Hill JH and Harada M. Assessing sensitivity to unmeasured confounding using simulated potential confounders (under review)