Usage
sensPlot(x, contour.levels = NULL, col.zero = "red", lty.zero = 1,
col.insig = "blue", lty.insig = 1, data.line = TRUE, X.pch = NULL,
signif.level = 0.05, labcex = 0.75, limit.Xplot = FALSE, txtlab = FALSE,
which.txtlab = NULL,...)Arguments
x
output of GLM.sens. It must have a structure of sensitivity class.
contour.levels
numeric vector of levels at which to draw contour lines. The default is NULL.
col.zero
color of the contour representing the combination of zetas that lead to the treatment effect estimate of 0. The default is "red".
lty.zero
line type of the contour representing the combination of zetas that lead to the treatment effect estimate of 0. The default is 1 (solid line).
col.insig
color of the contour representing the combination of zetas that makes the treatment effect estimate statistically insignificant at a given level. The default is "blue".
lty.insig
line type of the contour representing the combination of zetas that makes the treatment effect estimate statistically insignificant at a given level. The default is 1 (solid line)
data.line
logical. If TRUE a grey contour corresponding to the treatment effect estimate obtained with sensitivity parameters set equal to the coefficients (across all observed confounders) that are farthest from the origin (0,0). The default is
X.pch
vector of length 2 giving plotting symbols confounders with a positive association with the
outcome and a negative association with the outcome, respectively. The default is c(3,6).
signif.level
this option specifies the statistical significance level at which the significance contour is drawn. The default is 0.05.
labcex
letter size of the treatment effect estimates on the contours. The default is 0.75.
limit.Xplot
logical. If TRUE this option limits the plot region to the minimum and the maximum of the sensitivity parameters and the covariates are plotted on the left or the right end of the figure. If FALSE the contour is extended to the c
txtlab
logical. Label plotted covariates with variable name.
which.txtlab
numeric vector of covariates to include, i.e. c(1:3) shows labels for first three covariates.
...
Other arguments to be passed to all calls to contour